<?php
/**
 * Appify functions and definitions
 *
 * @package Appify
 * @since Appify 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since Appify 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

if ( ! function_exists( 'appify_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since Appify 1.0
 */
function appify_setup() {
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on Appify, use a find and replace
	 * to change 'appify' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'appify', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'main-feature', 460, 340, true );

	/**
	 * Custom Background
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'f8f8f8',
	) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'appify' ) );

	/**
	 * Shortcodes in hero description
	 */
	add_filter( 'appify_theme_mod_appify_hero_description', 'do_shortcode' );
}
endif;
add_action( 'after_setup_theme', 'appify_setup' );

/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @since Appify 1.0
 *
 * @param string $title The current page title
 * @param string $sep The separatator between title elements
 * @return string $title The newly formatted title
 */
function appify_wp_title( $title, $sep ) {
	global $page, $paged;

	if ( is_feed() )
		return $title;

	// Add the blog name
	$title .= get_bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $sep $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $sep " . sprintf( __( 'Page %s', 'appify' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'appify_wp_title', 10, 2 );

/**
 * Enqueue scripts and styles.
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_scripts() {
	/*
	 * Loads our special font CSS file.
	 *
	 * The use of Open Sans by default is localized. For languages that use
	 * characters not supported by the font, the font can be disabled.
	 *
	 * To disable in a child theme, use wp_dequeue_style()
	 * function mytheme_dequeue_fonts() {
	 *     wp_dequeue_style( 'twentytwelve-fonts' );
	 * }
	 * add_action( 'wp_enqueue_scripts', 'mytheme_dequeue_fonts', 11 );
	 */

	/* translators: If there are characters in your language that are not supported
	   by Open Sans, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'twentytwelve' ) ) {
		$subsets = 'latin,latin-ext';

		/* translators: To add an additional Open Sans character subset specific to your language, translate
		   this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language. */
		$subset = _x( 'no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'twentytwelve' );

		if ( 'cyrillic' == $subset )
			$subsets .= ',cyrillic,cyrillic-ext';
		elseif ( 'greek' == $subset )
			$subsets .= ',greek,greek-ext';
		elseif ( 'vietnamese' == $subset )
			$subsets .= ',vietnamese';

		$protocol = is_ssl() ? 'https' : 'http';
		$query_args = array(
			'family' => 'Radley:400italic|Goudy+Bookletter+1911|Open+Sans:400italic,700italic,400,700',
			'subset' => $subsets,
		);

		wp_enqueue_style( 'cloudify-fonts', add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" ), array(), null );
	}

	wp_enqueue_style( 'cloudify-style', get_stylesheet_uri(), array( 'cloudify-fonts' ), '20130212' );

	wp_enqueue_script( 'cloudify-jquery', get_template_directory_uri() . '/js/cloudify.js', array( 'jquery' ), '20130212' );
}
add_action( 'wp_enqueue_scripts', 'appify_scripts' );

/**
 * Remove menu items that are not being used. Simplify the theme by
 * removing comments, categories, tags.
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_simplifiy_admin() {
	remove_menu_page( 'edit-comments.php' );
	remove_submenu_page( 'edit.php', 'edit-tags.php?taxonomy=category' );
	remove_submenu_page( 'edit.php', 'edit-tags.php?taxonomy=post_tag' );
}
add_action( 'admin_menu', 'appify_simplifiy_admin' );

/**
 * Sections, Features, Testimonials
 */
require( get_template_directory() . '/inc/sections.php' );
require( get_template_directory() . '/inc/features.php' );
require( get_template_directory() . '/inc/testimonials.php' );

/**
 * Customize
 */
require( get_template_directory() . '/inc/custom-header.php' );
require( get_template_directory() . '/inc/customize.php' );

/**
 * Plugin Notice
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_features_notice() {
	?>
	<div class="updated">
		<p><?php printf( 
					__( '<strong>Notice:</strong> To take advantage of all of the great features Appify offers, please install the <a href="%s">Features</a> and <a href="%s">Testimonials</a> plugins. <a href="%s" class="alignright">Hide this message.</a>', 'appify' ), 
					wp_nonce_url( network_admin_url( 'update.php?action=install-plugin&plugin=features-by-woothemes' ), 'install-plugin_features-by-woothemes' ), 
					wp_nonce_url( network_admin_url( 'update.php?action=install-plugin&plugin=testimonials-by-woothemes' ), 'install-plugin_testimonials-by-woothemes' ), 
					wp_nonce_url( add_query_arg( array( 'action' => 'appify-hide-plugin-notice' ), admin_url( 'index.php' ) ), 'appify-hide-plugin-notice' ) 
			); ?></p>
	</div>
<?php
}
if ( ( ! appify_has_features() || ! appify_has_testimonials() ) && is_admin() && ! get_user_meta( get_current_user_id(), 'appify-hide-plugin-notice', true ) )
	add_action( 'admin_notices', 'appify_features_notice' );

/**
 * Hide plugin notice.
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_hide_plugin_notice() {
	check_admin_referer( 'appify-hide-plugin-notice' );

	$user_id = get_current_user_id();

	add_user_meta( $user_id, 'appify-hide-plugin-notice', 1 );
}
if ( is_admin() )
	add_action( 'admin_action_appify-hide-plugin-notice', 'appify_hide_plugin_notice' );