<?php
/**
 * Implements an optional custom header for Appify.
 * See http://codex.wordpress.org/Custom_Headers
 *
 * @package Appify
 * @since Appify 1.0
 */

/**
 * Sets up the WordPress core custom header arguments and settings.
 *
 * @uses add_theme_support() to register support for 3.4 and up.
 * @uses appify_header_style() to style front-end.
 * @uses appify_admin_header_style() to style wp-admin form.
 * @uses appify_admin_header_image() to add custom markup to wp-admin form.
 *
 * @since Appify 1.0
 */
function appify_custom_header_setup() {
	$args = array(
		'default-text-color'     => 'ffffff',
		'default-image'          => '',
		'height'                 => 250,
		'width'                  => 978,
		'max-width'              => 2000,
		'flex-height'            => true,
		'flex-width'             => true,
		'random-default'         => false,
		'wp-head-callback'       => 'appify_header_style',
		'admin-head-callback'    => 'appify_admin_header_style',
		'admin-preview-callback' => 'appify_admin_header_image',
	);

	add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'appify_custom_header_setup' );

/**
 * Styles the header text displayed on the blog.
 *
 * get_header_textcolor() options: 444 is default, hide text (returns 'blank'), or any hex value.
 *
 * @since Appify 1.0
 */
function appify_header_style() {
	$text_color = get_header_textcolor();
	
	// If no custom options for text are set, let's bail
	if ( $text_color == get_theme_support( 'custom-header', 'default-text-color' ) )
		return;

	// If we get this far, we have custom styles.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text, use that.
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo $text_color; ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}

/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * @since Appify 1.0
 */
function appify_admin_header_style() {
	wp_enqueue_style( 'google-fonts', 'http://fonts.googleapis.com/css?family=Radley:400italic' );
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		padding: 30px;
		width: 90%;
		border: none;
		background: <?php echo appify_theme_mod( 'hero_background_color' ); ?>
	}

	#headimg .site-title {
		font: italic 40px/normal 'Radley', Helvetica, Arial, sans-serif;
		margin: 0 0 -8px;
	}

	#headimg .site-title a {
		color: #ffffff;
		text-decoration: none;
	}

	#headimg .site-title a:hover {
		text-decoration: none;
	}

	#headimg .site-description {
		margin: 0;
		padding: 0;
		font-size: 12px;
		text-transform: uppercase;
		color: #ffffff;
		text-shadow: none;
	}

	#headimg .header-image {
		float: left;
		margin-right: 20px;
	}
	</style>
<?php
}

/**
 * Outputs markup to be displayed on the Appearance > Header admin panel.
 * This callback overrides the default markup displayed there.
 *
 * @since Appify 1.0
 */
function appify_admin_header_image() {
	?>
	<div id="headimg">
		<?php
		if ( ! display_header_text() )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_header_textcolor() . ';"';
		?>

		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $header_image ); ?>" class="header-image" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" /></a>
		<?php endif; ?>

		<h1 class="site-title"><a <?php echo $style; ?> id="name" onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
		<h2 <?php echo $style; ?> class="site-description" id="desc"><?php bloginfo( 'description' ); ?></h2>
	</div>
<?php }