<?php
/**
 * Features
 *
 * Features are the bits across the top of the page with an icon and a description. 
 * They are powered by WooTheme's Features plugin.
 *
 * @see http://wordpress.org/extend/plugins/features-by-woothemes/
 *
 * @package Appify
 * @since Appify 1.0
 */

/**
 * Check if the Features plugin is activated.
 *
 * @since Appify 1.0
 *
 * @return boolean If the plugin is active or not.
 */
function appify_has_features() {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	
	return is_plugin_active( 'features-by-woothemes/woothemes-features.php' );
}

/**
 * Make some small adjustments to the default arguments for the
 * Features shortcode.
 *
 * @since Appify 1.0
 *
 * @param array $args The default arguments for the shortcode
 * @return array $args The adjusted arguments for the shortcode
 */
function appify_features_args( $args ) {
	$args[ 'before' ]     = '<section class="call_to_action">';
	$args[ 'after' ]      = '</section>';
	$args[ 'link_title' ] = false;
	$args[ 'per_row' ]    = 100;

	return $args;
}
add_filter( 'woothemes_features_args', 'appify_features_args' );

/**
 * Custom template for the each feature output.
 *
 * @since Appify 1.0
 *
 * @param string $tpl The default template (overwritten completely)
 * @param array $args The default arguments for the template
 * @return string $tpl The adjusted HTML template
 */
function appify_features_item_template( $tpl, $args ) {
	$tpl = '<article class="%%CLASS%%">
				<div class="tooltip">%%CONTENT%%</div> 
				<div class="pic" style="background-color: %%COLOR%%">%%ICON%%</div> 
				<h3>%%TITLE%%</h3>
			</article>';

	return $tpl;
}
add_filter( 'woothemes_features_item_template', 'appify_features_item_template', 10, 2 );

/**
 * Add the ability to set a color when creating a feature.
 *
 * This can be an HTML text color (white, black, red, etc) or a HEX value
 * (#ffffff, #fff000, etc)
 *
 * @since Appify 1.0
 *
 * @param array $settings The default settings for the metabox
 * @return array $args The adjusted settings for the metabox
 */
function appify_features_custom_fields_settings( $settings ) {
	$settings[ 'color' ] = array(
		'name' => __( 'Color', 'appify' ), 
	    'description' => __( 'Enter color. If HEX, include the #.', 'appify' ), 
	    'type' => 'text', 
	    'default' => '', 
	    'section' => 'info'
	);

	return $settings;
}
add_filter( 'woothemes_features_custom_fields_settings', 'appify_features_custom_fields_settings' );

/**
 * Custom values for our custom template
 *
 * Replace the custom template tags with relevant data.
 *
 * @since Appify 1.0
 *
 * @param string $template The HTML markup with the template tags
 * @param object $post The current post object
 * @return string $template The new HTML with some template tags replaced
 */
function appify_features_template( $template, $post ) {
	$color = get_post_meta( $post->ID, '_color', true );
	$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'feature-thumbnail', false );
	
	$template = str_replace( '%%COLOR%%', $color, $template );
	$template = str_replace( '%%ICON%%', sprintf( '<img src="%s" width="%d" height="%d" alt="" />', $image[0], $image[1], $image[2] ), $template );

	return $template;
}
add_filter( 'woothemes_features_template', 'appify_features_template', 10, 2 );