<?php
/**
 * Sections
 *
 * Sections are the content + images in the main part of the template.
 * They can be used to outline features, give updates, or anything else.
 *
 * They work like standard WordPress posts. Simply define a title, content,
 * and set a featured image. New sections will appear automatically in the order
 * they are added.
 *
 * @package Appify
 * @since Appify 1.0
 */

/**
 * Remove unused post type features for Sections. The only items
 * needed are title, content, and featured image.
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_remove_metaboxes_support() {
	$remove = array( 'slug', 'excerpt', 'author', 'trackbacks', 'comments', 'page-attributes', 'post_tag' );

	foreach ( $remove as $to )
		remove_post_type_support( 'post', $to );
}
add_action( 'init', 'appify_remove_metaboxes_support' );

/**
 * Remove metaboxes for the Section post type. These
 * can't be removed via `remove_post_type_support()` (as far
 * as I am aware, so the actual metaboxes themselves need to be
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_remove_metaboxes_manual() {
	remove_meta_box( 'tagsdiv-post_tag', 'post', 'side' );
	remove_meta_box( 'categorydiv', 'post', 'side' );
}
add_action( 'admin_menu' , 'appify_remove_metaboxes_manual' );

/**
 * Remove columns from the Sections table. No need to show information
 * that is not being set.
 *
 * @since Appify 1.0
 *
 * @param array $columns The array of columns to be displayed
 * @return array $columns The modified array of columns to be displayed
 */
function appify_edit_post_columns( $columns ) {
	unset( $columns[ 'categories' ] );
	unset( $columns[ 'author' ] );
	unset( $columns[ 'tags' ] );
	unset( $columns[ 'date' ] );
	unset( $columns[ 'comments' ] );

	return $columns;
}
add_filter( 'manage_edit-post_columns', 'appify_edit_post_columns' ) ;

/**
 * Update the "Post" labels to reflect what we are calling "Sections"
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_change_post_object_label() {
	global $wp_post_types;
	
	$labels = $wp_post_types['post']->labels;

	$labels->name               = __( 'Sections', 'appify' );
	$labels->all_items          = __( 'Sections', 'appify' );
	$Labels->menu_name          = __( 'Sections', 'appify' );
	$labels->singular_name      = __( 'Sections', 'appify' );
	$labels->add_new            = __( 'Add Section', 'appify' );
	$labels->add_new_item       = __( 'Add Section', 'appify' );
	$labels->edit_item          = __( 'Edit Section', 'appify' );
	$labels->new_item           = __( 'Sections', 'appify' );
	$labels->view_item          = __( 'View Sections', 'appify' );
	$labels->search_items       = __( 'Search Sections', 'appify' );
	$labels->not_found          = __( 'No sections found', 'appify' );
	$labels->not_found_in_trash = __( 'No sections found in trash', 'appify' );
}
add_action( 'init', 'appify_change_post_object_label', 1 );

/**
 * Update the "Post" labels to reflect what we are calling "Sections"
 *
 * @since Appify 1.0
 *
 * @return void
 */
function appify_change_post_menu_label() {
	global $menu,  $submenu;
	
	$menu[5][0] = __( 'Sections', 'appify' );
	$submenu['edit.php'][5][0] = __( 'Sections', 'appify' );

	echo '';
}
add_action( 'admin_menu', 'appify_change_post_menu_label' );

/**
 * Add odd/even classes to each section so images can be aligned.
 *
 * @since Appify 1.0
 *
 * @param array $classes An array of post classes
 * @return array $calsses An adjusted array of post classes
 */
function appify_post_class( $classes ) {
	global $current_class;

	if ( ! isset( $current_class ) )
		$current_class = 'odd';

	$classes[] = $current_class;

	$current_class = $current_class == 'odd' ? 'even' : 'odd';
	
	return $classes;
}
add_filter( 'post_class' , 'appify_post_class' );